@@ -7,19 +7,27 @@ use Data::Printer;
 
 with 'WebService::Client';
 # ABSTRACT: Perl 5 interface to Pixabay API.
-our $VERSION = '0.0.6'; # VERSION
+our $VERSION = '1.0.0'; our $VERSION = '1.0.0'; # VERSION
 
+# token key
 has api_key =>
 (
-	is => 'ro', 
+	is => 'ro',
 	required => 1
 );
 
+# object for holding json data
+has json_data => 
+(
+	is => 'rw'
+);
+
 has '+base_url' =>
 (
 	default => 'https://pixabay.com/api/'
 );
 
+# get image metadata from JSON
 method image_search
 (
 	:$q = "yellow flower", :$lang = "en", :$id = "", :$response_group = "image_details",
@@ -28,16 +36,19 @@ method image_search
 	:$page = 1, :$per_page = 20, :$callback = "", :$pretty = "false"
 )
 {
-	return $self->get
+	$self->json_data($self->get
 	(
 		"?key=" . $self->api_key .
 						 "&q=$q&lang=$lang&id=$id&response_group=$response_group&image_type=$image_type" .
 						 "&orientation=$orientation&category=$category&min_width=$min_width&mind_height=$min_height" .
 					     "&editors_choice=$editors_choice&safesearch=$safesearch&order=$order&page=$page" .
 					     "&per_page=$per_page&callback=$callback&pretty=$pretty"
-	);
+	));
+
+	return $self;
 }
 
+# get image metadata from JSON
 method video_search
 (	:$q = "yellow flower", :$lang = "en", :$id = "", :$video_type = "all",
 	:$category = "", :$min_width = 0, :$min_height = 0,
@@ -45,19 +56,22 @@ method video_search
 	:$page = 1, :$per_page = 20, :$callback = "", :$pretty = "false"
 )
 {
-	return $self->get
+	$self->json_data($self->get
 	(
 		"videos/?key=" . $self->api_key .
 						 "&q=$q&lang=$lang&id=$id&video_type=$video_type" .
 					     "&category=$category&min_width=$min_width&mind_height=$min_height" .
 					     "&editors_choice=$editors_choice&safesearch=$safesearch&order=$order&page=$page" .
 					     "&per_page=$per_page&callback=$callback&pretty=$pretty"
-	);
+	));
+
+	return $self;
 }
 
-method show_data_structure($method_name)
+# pretty print the JSON data structure
+method show_data_structure()
 {
-	return p $method_name;
+	return p $self->json_data;
 }
 
 1;
@@ -74,7 +88,7 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 0.0.6
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -82,19 +96,20 @@ version 0.0.6
 	
 	my $pix = WebService::Pixabay->new(api_key => 'secret');
 	
-	# default searches
+	 default searches
 	my $img_search = $pix->image_search();
 	my $vid_search = $pix->video_search();
-
-	$pix->show_data_structure($img_search);
-	$pix->show_data_structure($vid_search);
+	
+	# show data structure using Data::Printer pretty print.
+	$img_search->show_data_structure;
+	$vid_search->show_data_structure;
 	
 	###################################################
 	# The parameters of the method have the same name #
 	# and default values as in Pixabay API docs       #
 	###################################################
 
-	# example custom image search
+	# example custom image search and printing
 	my $nis = $pix->image_search(
 		q => 'cats dog',
 		lang => 'es',
@@ -108,27 +123,43 @@ version 0.0.6
 		pretty => 'true'
 	);
 
-	# example custom video search
+	$nis->show_data_structure;
+
+	# -or-
+
+	# example custom video search and printing
 	my $nvs = $pix->video_search(
 		q => 'tree',
 		lang => 'en',
 		pretty => 'false',
 		page => 3,
 		order => 'popular'
-	);
-
-
-	$pix->show_data_structure($nis);
-	$pix->show_data_structure($nvs);
+	)->show_data_structure;
 
+	# Handling specific hash and arrays of values from the JSON
 	# example retrieving webformatURL from each arrays
 	my @urls = undef;
-
-	foreach my $url (@{$img_search->{hits}}) {
-		
+	
+	# note the 'json_data' object usage
+	foreach my $url (@{$nis->json_data->{hits}}) {
 		# now has link of photo urls (non-preview photos)
 		push(@urls, $url->{webformatURL});		
 	}
+	
+	say $urls[3]; # image URL
+
+	# Getting a specific single key or array value
+	say $nis->image_search(q => 'cloud')
+		->json_data
+		->{hits}[2]{webformatURL};
+
+=head1 NAME
+
+WebService::Pixabay - Perl 5 interface to Pixabay API.
+
+=head1 VERSION
+
+version 0.1.0
 
 =head1 SEE ALSO
 
@@ -157,4 +188,15 @@ This software is copyright (c) 2017 by faraco.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHOR
+
+faraco <skelic3@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by faraco.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
